==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/WebSummaryResultDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebSummaryResultDescription } from "./WebSummaryResultDescription";
/**
 * @hidden
 */
export let WebSummaryResultDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebSummaryResultDescriptionMetadata extends Base {
        static b(a) {
            if (WebSummaryResultDescriptionMetadata.a == null) {
                WebSummaryResultDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebSummaryResultDescriptionMetadata.c(WebSummaryResultDescriptionMetadata.a);
            }
            if (a.j(WebSummaryResultDescriptionMetadata.a)) {
                return;
            }
            a.y(WebSummaryResultDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:SummaryResult");
            a.item("__packageNameWC", "String:grids");
            a.item("__isPlainObject", "Boolean");
            a.item("Key", "String");
            a.item("Label", "String");
            a.item("Result", "(wc:SummaryResult)Unknown");
            a.item("DefaultFormatting", "Boolean");
        }
        static d(a) {
            WebSummaryResultDescriptionMetadata.b(a);
            a.aa("WebSummaryResult", () => new WebSummaryResultDescription());
            a.z("WebSummaryResult", WebSummaryResultDescriptionMetadata.a);
        }
    }
    WebSummaryResultDescriptionMetadata.$t = /*@__PURE__*/ markType(WebSummaryResultDescriptionMetadata, 'WebSummaryResultDescriptionMetadata');
    WebSummaryResultDescriptionMetadata.a = null;
    return WebSummaryResultDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/WebSummaryResultDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebSummaryResultDescription } from "./WebSummaryResultDescription";
/**
 * @hidden
 */
export let WebSummaryResultDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebSummaryResultDescriptionMetadata extends Base {
        static b(a) {
            if (WebSummaryResultDescriptionMetadata.a == null) {
                WebSummaryResultDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebSummaryResultDescriptionMetadata.c(WebSummaryResultDescriptionMetadata.a);
            }
            if (a.k(WebSummaryResultDescriptionMetadata.a)) {
                return;
            }
            a.aa(WebSummaryResultDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:SummaryResult");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__isPlainObject", "Boolean");
            a.item("__skipSuffix", "Boolean");
            a.item("Key", "String");
            a.item("Label", "String");
            a.item("Result", "(wc:SummaryResult)Unknown");
            a.item("DefaultFormatting", "Boolean");
        }
        static d(a) {
            WebSummaryResultDescriptionMetadata.b(a);
            a.ac("WebSummaryResult", () => new WebSummaryResultDescription());
            a.ab("WebSummaryResult", WebSummaryResultDescriptionMetadata.a);
        }
    }
    WebSummaryResultDescriptionMetadata.$t = /*@__PURE__*/ markType(WebSummaryResultDescriptionMetadata, 'WebSummaryResultDescriptionMetadata');
    WebSummaryResultDescriptionMetadata.a = null;
    return WebSummaryResultDescriptionMetadata;
})();
